pub fn clear_jit_cache()Expand description
Clear the process-global JIT compilation cache.
Call this when source files have changed and cached compiled code may be stale.
pub fn clear_jit_cache()Clear the process-global JIT compilation cache.
Call this when source files have changed and cached compiled code may be stale.