run_test

Function run_test 

pub fn run_test(
    env: Env,
    sources: Vec<NapiSourceFile>,
    top: String,
    options: Option<NapiOptions>,
    components: Option<Vec<NapiInjectedComponent>>,
) -> Result<NapiTestResult>
Run a native testbench from Veryl source code.

Compiles the given sources and runs the #[test] module specified by top, returning assertion results observed before that test finishes or stops on a fatal failure.